# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BookmarkArgs', 'Bookmark']

@pulumi.input_type
class BookmarkArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 url: pulumi.Input[builtins.str],
                 accessibility_error_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_policy: Optional[pulumi.Input[builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[builtins.bool]] = None,
                 enduser_note: Optional[pulumi.Input[builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[builtins.bool]] = None,
                 logo: Optional[pulumi.Input[builtins.str]] = None,
                 request_integration: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Bookmark resource.
        :param pulumi.Input[builtins.str] label: The Application's display name.
        :param pulumi.Input[builtins.str] url: The URL of the bookmark.
        :param pulumi.Input[builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[builtins.str] authentication_policy: The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        :param pulumi.Input[builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[builtins.bool] request_integration: Would you like Okta to add an integration for this app?
        :param pulumi.Input[builtins.str] status: Status of application. By default, it is `ACTIVE`
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "url", url)
        if accessibility_error_redirect_url is not None:
            pulumi.set(__self__, "accessibility_error_redirect_url", accessibility_error_redirect_url)
        if accessibility_login_redirect_url is not None:
            pulumi.set(__self__, "accessibility_login_redirect_url", accessibility_login_redirect_url)
        if accessibility_self_service is not None:
            pulumi.set(__self__, "accessibility_self_service", accessibility_self_service)
        if admin_note is not None:
            pulumi.set(__self__, "admin_note", admin_note)
        if app_links_json is not None:
            pulumi.set(__self__, "app_links_json", app_links_json)
        if authentication_policy is not None:
            pulumi.set(__self__, "authentication_policy", authentication_policy)
        if auto_submit_toolbar is not None:
            pulumi.set(__self__, "auto_submit_toolbar", auto_submit_toolbar)
        if enduser_note is not None:
            pulumi.set(__self__, "enduser_note", enduser_note)
        if hide_ios is not None:
            pulumi.set(__self__, "hide_ios", hide_ios)
        if hide_web is not None:
            pulumi.set(__self__, "hide_web", hide_web)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if request_integration is not None:
            pulumi.set(__self__, "request_integration", request_integration)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        The Application's display name.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[builtins.str]:
        """
        The URL of the bookmark.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="accessibilityErrorRedirectUrl")
    def accessibility_error_redirect_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom error page URL
        """
        return pulumi.get(self, "accessibility_error_redirect_url")

    @accessibility_error_redirect_url.setter
    def accessibility_error_redirect_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility_error_redirect_url", value)

    @property
    @pulumi.getter(name="accessibilityLoginRedirectUrl")
    def accessibility_login_redirect_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom login page URL
        """
        return pulumi.get(self, "accessibility_login_redirect_url")

    @accessibility_login_redirect_url.setter
    def accessibility_login_redirect_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility_login_redirect_url", value)

    @property
    @pulumi.getter(name="accessibilitySelfService")
    def accessibility_self_service(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable self service. Default is `false`
        """
        return pulumi.get(self, "accessibility_self_service")

    @accessibility_self_service.setter
    def accessibility_self_service(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "accessibility_self_service", value)

    @property
    @pulumi.getter(name="adminNote")
    def admin_note(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Application notes for admins.
        """
        return pulumi.get(self, "admin_note")

    @admin_note.setter
    def admin_note(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "admin_note", value)

    @property
    @pulumi.getter(name="appLinksJson")
    def app_links_json(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Displays specific appLinks for the app. The value for each application link should be boolean.
        """
        return pulumi.get(self, "app_links_json")

    @app_links_json.setter
    def app_links_json(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "app_links_json", value)

    @property
    @pulumi.getter(name="authenticationPolicy")
    def authentication_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        """
        return pulumi.get(self, "authentication_policy")

    @authentication_policy.setter
    def authentication_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_policy", value)

    @property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @auto_submit_toolbar.setter
    def auto_submit_toolbar(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_submit_toolbar", value)

    @property
    @pulumi.getter(name="enduserNote")
    def enduser_note(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Application notes for end users.
        """
        return pulumi.get(self, "enduser_note")

    @enduser_note.setter
    def enduser_note(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enduser_note", value)

    @property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @hide_ios.setter
    def hide_ios(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hide_ios", value)

    @property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @hide_web.setter
    def hide_web(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hide_web", value)

    @property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "logo", value)

    @property
    @pulumi.getter(name="requestIntegration")
    def request_integration(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Would you like Okta to add an integration for this app?
        """
        return pulumi.get(self, "request_integration")

    @request_integration.setter
    def request_integration(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "request_integration", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status of application. By default, it is `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _BookmarkState:
    def __init__(__self__, *,
                 accessibility_error_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_policy: Optional[pulumi.Input[builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[builtins.bool]] = None,
                 enduser_note: Optional[pulumi.Input[builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[builtins.bool]] = None,
                 label: Optional[pulumi.Input[builtins.str]] = None,
                 logo: Optional[pulumi.Input[builtins.str]] = None,
                 logo_url: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 request_integration: Optional[pulumi.Input[builtins.bool]] = None,
                 sign_on_mode: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Bookmark resources.
        :param pulumi.Input[builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[builtins.str] authentication_policy: The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        :param pulumi.Input[builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[builtins.str] label: The Application's display name.
        :param pulumi.Input[builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[builtins.str] logo_url: URL of the application's logo
        :param pulumi.Input[builtins.str] name: Name of the app.
        :param pulumi.Input[builtins.bool] request_integration: Would you like Okta to add an integration for this app?
        :param pulumi.Input[builtins.str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[builtins.str] url: The URL of the bookmark.
        """
        if accessibility_error_redirect_url is not None:
            pulumi.set(__self__, "accessibility_error_redirect_url", accessibility_error_redirect_url)
        if accessibility_login_redirect_url is not None:
            pulumi.set(__self__, "accessibility_login_redirect_url", accessibility_login_redirect_url)
        if accessibility_self_service is not None:
            pulumi.set(__self__, "accessibility_self_service", accessibility_self_service)
        if admin_note is not None:
            pulumi.set(__self__, "admin_note", admin_note)
        if app_links_json is not None:
            pulumi.set(__self__, "app_links_json", app_links_json)
        if authentication_policy is not None:
            pulumi.set(__self__, "authentication_policy", authentication_policy)
        if auto_submit_toolbar is not None:
            pulumi.set(__self__, "auto_submit_toolbar", auto_submit_toolbar)
        if enduser_note is not None:
            pulumi.set(__self__, "enduser_note", enduser_note)
        if hide_ios is not None:
            pulumi.set(__self__, "hide_ios", hide_ios)
        if hide_web is not None:
            pulumi.set(__self__, "hide_web", hide_web)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if logo_url is not None:
            pulumi.set(__self__, "logo_url", logo_url)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if request_integration is not None:
            pulumi.set(__self__, "request_integration", request_integration)
        if sign_on_mode is not None:
            pulumi.set(__self__, "sign_on_mode", sign_on_mode)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="accessibilityErrorRedirectUrl")
    def accessibility_error_redirect_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom error page URL
        """
        return pulumi.get(self, "accessibility_error_redirect_url")

    @accessibility_error_redirect_url.setter
    def accessibility_error_redirect_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility_error_redirect_url", value)

    @property
    @pulumi.getter(name="accessibilityLoginRedirectUrl")
    def accessibility_login_redirect_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom login page URL
        """
        return pulumi.get(self, "accessibility_login_redirect_url")

    @accessibility_login_redirect_url.setter
    def accessibility_login_redirect_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "accessibility_login_redirect_url", value)

    @property
    @pulumi.getter(name="accessibilitySelfService")
    def accessibility_self_service(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable self service. Default is `false`
        """
        return pulumi.get(self, "accessibility_self_service")

    @accessibility_self_service.setter
    def accessibility_self_service(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "accessibility_self_service", value)

    @property
    @pulumi.getter(name="adminNote")
    def admin_note(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Application notes for admins.
        """
        return pulumi.get(self, "admin_note")

    @admin_note.setter
    def admin_note(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "admin_note", value)

    @property
    @pulumi.getter(name="appLinksJson")
    def app_links_json(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Displays specific appLinks for the app. The value for each application link should be boolean.
        """
        return pulumi.get(self, "app_links_json")

    @app_links_json.setter
    def app_links_json(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "app_links_json", value)

    @property
    @pulumi.getter(name="authenticationPolicy")
    def authentication_policy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        """
        return pulumi.get(self, "authentication_policy")

    @authentication_policy.setter
    def authentication_policy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authentication_policy", value)

    @property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @auto_submit_toolbar.setter
    def auto_submit_toolbar(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_submit_toolbar", value)

    @property
    @pulumi.getter(name="enduserNote")
    def enduser_note(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Application notes for end users.
        """
        return pulumi.get(self, "enduser_note")

    @enduser_note.setter
    def enduser_note(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enduser_note", value)

    @property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @hide_ios.setter
    def hide_ios(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hide_ios", value)

    @property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @hide_web.setter
    def hide_web(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hide_web", value)

    @property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Application's display name.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "logo", value)

    @property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URL of the application's logo
        """
        return pulumi.get(self, "logo_url")

    @logo_url.setter
    def logo_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "logo_url", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the app.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="requestIntegration")
    def request_integration(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Would you like Okta to add an integration for this app?
        """
        return pulumi.get(self, "request_integration")

    @request_integration.setter
    def request_integration(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "request_integration", value)

    @property
    @pulumi.getter(name="signOnMode")
    def sign_on_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Sign on mode of application.
        """
        return pulumi.get(self, "sign_on_mode")

    @sign_on_mode.setter
    def sign_on_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sign_on_mode", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status of application. By default, it is `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The URL of the bookmark.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("okta:app/bookmark:Bookmark")
class Bookmark(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility_error_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_policy: Optional[pulumi.Input[builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[builtins.bool]] = None,
                 enduser_note: Optional[pulumi.Input[builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[builtins.bool]] = None,
                 label: Optional[pulumi.Input[builtins.str]] = None,
                 logo: Optional[pulumi.Input[builtins.str]] = None,
                 request_integration: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to create and configure a Bookmark Application.
        > During an apply if there is change in status the app will first be
        activated or deactivated in accordance with the status change. Then, all
        other arguments that changed will be applied.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.Bookmark("example",
            label="Example",
            url="https://example.com")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/bookmark:Bookmark example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[builtins.str] authentication_policy: The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        :param pulumi.Input[builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[builtins.str] label: The Application's display name.
        :param pulumi.Input[builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[builtins.bool] request_integration: Would you like Okta to add an integration for this app?
        :param pulumi.Input[builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[builtins.str] url: The URL of the bookmark.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BookmarkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and configure a Bookmark Application.
        > During an apply if there is change in status the app will first be
        activated or deactivated in accordance with the status change. Then, all
        other arguments that changed will be applied.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.Bookmark("example",
            label="Example",
            url="https://example.com")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/bookmark:Bookmark example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param BookmarkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BookmarkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility_error_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[builtins.str]] = None,
                 authentication_policy: Optional[pulumi.Input[builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[builtins.bool]] = None,
                 enduser_note: Optional[pulumi.Input[builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[builtins.bool]] = None,
                 label: Optional[pulumi.Input[builtins.str]] = None,
                 logo: Optional[pulumi.Input[builtins.str]] = None,
                 request_integration: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BookmarkArgs.__new__(BookmarkArgs)

            __props__.__dict__["accessibility_error_redirect_url"] = accessibility_error_redirect_url
            __props__.__dict__["accessibility_login_redirect_url"] = accessibility_login_redirect_url
            __props__.__dict__["accessibility_self_service"] = accessibility_self_service
            __props__.__dict__["admin_note"] = admin_note
            __props__.__dict__["app_links_json"] = app_links_json
            __props__.__dict__["authentication_policy"] = authentication_policy
            __props__.__dict__["auto_submit_toolbar"] = auto_submit_toolbar
            __props__.__dict__["enduser_note"] = enduser_note
            __props__.__dict__["hide_ios"] = hide_ios
            __props__.__dict__["hide_web"] = hide_web
            if label is None and not opts.urn:
                raise TypeError("Missing required property 'label'")
            __props__.__dict__["label"] = label
            __props__.__dict__["logo"] = logo
            __props__.__dict__["request_integration"] = request_integration
            __props__.__dict__["status"] = status
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["logo_url"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["sign_on_mode"] = None
        super(Bookmark, __self__).__init__(
            'okta:app/bookmark:Bookmark',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessibility_error_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
            accessibility_login_redirect_url: Optional[pulumi.Input[builtins.str]] = None,
            accessibility_self_service: Optional[pulumi.Input[builtins.bool]] = None,
            admin_note: Optional[pulumi.Input[builtins.str]] = None,
            app_links_json: Optional[pulumi.Input[builtins.str]] = None,
            authentication_policy: Optional[pulumi.Input[builtins.str]] = None,
            auto_submit_toolbar: Optional[pulumi.Input[builtins.bool]] = None,
            enduser_note: Optional[pulumi.Input[builtins.str]] = None,
            hide_ios: Optional[pulumi.Input[builtins.bool]] = None,
            hide_web: Optional[pulumi.Input[builtins.bool]] = None,
            label: Optional[pulumi.Input[builtins.str]] = None,
            logo: Optional[pulumi.Input[builtins.str]] = None,
            logo_url: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            request_integration: Optional[pulumi.Input[builtins.bool]] = None,
            sign_on_mode: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None) -> 'Bookmark':
        """
        Get an existing Bookmark resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[builtins.str] authentication_policy: The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        :param pulumi.Input[builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[builtins.str] label: The Application's display name.
        :param pulumi.Input[builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[builtins.str] logo_url: URL of the application's logo
        :param pulumi.Input[builtins.str] name: Name of the app.
        :param pulumi.Input[builtins.bool] request_integration: Would you like Okta to add an integration for this app?
        :param pulumi.Input[builtins.str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[builtins.str] url: The URL of the bookmark.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BookmarkState.__new__(_BookmarkState)

        __props__.__dict__["accessibility_error_redirect_url"] = accessibility_error_redirect_url
        __props__.__dict__["accessibility_login_redirect_url"] = accessibility_login_redirect_url
        __props__.__dict__["accessibility_self_service"] = accessibility_self_service
        __props__.__dict__["admin_note"] = admin_note
        __props__.__dict__["app_links_json"] = app_links_json
        __props__.__dict__["authentication_policy"] = authentication_policy
        __props__.__dict__["auto_submit_toolbar"] = auto_submit_toolbar
        __props__.__dict__["enduser_note"] = enduser_note
        __props__.__dict__["hide_ios"] = hide_ios
        __props__.__dict__["hide_web"] = hide_web
        __props__.__dict__["label"] = label
        __props__.__dict__["logo"] = logo
        __props__.__dict__["logo_url"] = logo_url
        __props__.__dict__["name"] = name
        __props__.__dict__["request_integration"] = request_integration
        __props__.__dict__["sign_on_mode"] = sign_on_mode
        __props__.__dict__["status"] = status
        __props__.__dict__["url"] = url
        return Bookmark(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessibilityErrorRedirectUrl")
    def accessibility_error_redirect_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Custom error page URL
        """
        return pulumi.get(self, "accessibility_error_redirect_url")

    @property
    @pulumi.getter(name="accessibilityLoginRedirectUrl")
    def accessibility_login_redirect_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Custom login page URL
        """
        return pulumi.get(self, "accessibility_login_redirect_url")

    @property
    @pulumi.getter(name="accessibilitySelfService")
    def accessibility_self_service(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Enable self service. Default is `false`
        """
        return pulumi.get(self, "accessibility_self_service")

    @property
    @pulumi.getter(name="adminNote")
    def admin_note(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Application notes for admins.
        """
        return pulumi.get(self, "admin_note")

    @property
    @pulumi.getter(name="appLinksJson")
    def app_links_json(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Displays specific appLinks for the app. The value for each application link should be boolean.
        """
        return pulumi.get(self, "app_links_json")

    @property
    @pulumi.getter(name="authenticationPolicy")
    def authentication_policy(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the associated app*signon*policy. If this property is removed from the application the default sign-on-policy will be associated with this application.
        """
        return pulumi.get(self, "authentication_policy")

    @property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @property
    @pulumi.getter(name="enduserNote")
    def enduser_note(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Application notes for end users.
        """
        return pulumi.get(self, "enduser_note")

    @property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @property
    @pulumi.getter
    def label(self) -> pulumi.Output[builtins.str]:
        """
        The Application's display name.
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def logo(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        """
        return pulumi.get(self, "logo")

    @property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> pulumi.Output[builtins.str]:
        """
        URL of the application's logo
        """
        return pulumi.get(self, "logo_url")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the app.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="requestIntegration")
    def request_integration(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Would you like Okta to add an integration for this app?
        """
        return pulumi.get(self, "request_integration")

    @property
    @pulumi.getter(name="signOnMode")
    def sign_on_mode(self) -> pulumi.Output[builtins.str]:
        """
        Sign on mode of application.
        """
        return pulumi.get(self, "sign_on_mode")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Status of application. By default, it is `ACTIVE`
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        The URL of the bookmark.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetNetworkZoneResult',
    'AwaitableGetNetworkZoneResult',
    'get_network_zone',
    'get_network_zone_output',
]

@pulumi.output_type
class GetNetworkZoneResult:
    """
    A collection of values returned by getNetworkZone.
    """
    def __init__(__self__, asns=None, dynamic_locations=None, dynamic_locations_excludes=None, dynamic_proxy_type=None, gateways=None, id=None, ip_service_categories_excludes=None, ip_service_categories_includes=None, name=None, proxies=None, status=None, type=None, usage=None):
        if asns and not isinstance(asns, list):
            raise TypeError("Expected argument 'asns' to be a list")
        pulumi.set(__self__, "asns", asns)
        if dynamic_locations and not isinstance(dynamic_locations, list):
            raise TypeError("Expected argument 'dynamic_locations' to be a list")
        pulumi.set(__self__, "dynamic_locations", dynamic_locations)
        if dynamic_locations_excludes and not isinstance(dynamic_locations_excludes, list):
            raise TypeError("Expected argument 'dynamic_locations_excludes' to be a list")
        pulumi.set(__self__, "dynamic_locations_excludes", dynamic_locations_excludes)
        if dynamic_proxy_type and not isinstance(dynamic_proxy_type, str):
            raise TypeError("Expected argument 'dynamic_proxy_type' to be a str")
        pulumi.set(__self__, "dynamic_proxy_type", dynamic_proxy_type)
        if gateways and not isinstance(gateways, list):
            raise TypeError("Expected argument 'gateways' to be a list")
        pulumi.set(__self__, "gateways", gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_service_categories_excludes and not isinstance(ip_service_categories_excludes, list):
            raise TypeError("Expected argument 'ip_service_categories_excludes' to be a list")
        pulumi.set(__self__, "ip_service_categories_excludes", ip_service_categories_excludes)
        if ip_service_categories_includes and not isinstance(ip_service_categories_includes, list):
            raise TypeError("Expected argument 'ip_service_categories_includes' to be a list")
        pulumi.set(__self__, "ip_service_categories_includes", ip_service_categories_includes)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if proxies and not isinstance(proxies, list):
            raise TypeError("Expected argument 'proxies' to be a list")
        pulumi.set(__self__, "proxies", proxies)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if usage and not isinstance(usage, str):
            raise TypeError("Expected argument 'usage' to be a str")
        pulumi.set(__self__, "usage", usage)

    @property
    @pulumi.getter
    def asns(self) -> Sequence[builtins.str]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> Sequence[builtins.str]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> Optional[Sequence[builtins.str]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> builtins.str:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @property
    @pulumi.getter
    def gateways(self) -> Sequence[builtins.str]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        ID of the network zone to retrieve, conflicts with `name`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> Optional[Sequence[builtins.str]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> Optional[Sequence[builtins.str]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Name of the network zone to retrieve, conflicts with `id`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def proxies(self) -> Sequence[builtins.str]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Network Status - can either be ACTIVE or INACTIVE only
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def usage(self) -> builtins.str:
        """
        Zone's purpose: POLICY or BLOCKLIST
        """
        return pulumi.get(self, "usage")


class AwaitableGetNetworkZoneResult(GetNetworkZoneResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkZoneResult(
            asns=self.asns,
            dynamic_locations=self.dynamic_locations,
            dynamic_locations_excludes=self.dynamic_locations_excludes,
            dynamic_proxy_type=self.dynamic_proxy_type,
            gateways=self.gateways,
            id=self.id,
            ip_service_categories_excludes=self.ip_service_categories_excludes,
            ip_service_categories_includes=self.ip_service_categories_includes,
            name=self.name,
            proxies=self.proxies,
            status=self.status,
            type=self.type,
            usage=self.usage)


def get_network_zone(dynamic_locations_excludes: Optional[Sequence[builtins.str]] = None,
                     id: Optional[builtins.str] = None,
                     ip_service_categories_excludes: Optional[Sequence[builtins.str]] = None,
                     ip_service_categories_includes: Optional[Sequence[builtins.str]] = None,
                     name: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkZoneResult:
    """
    Gets Okta Network Zone.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_network_zone(name="Block Antarctica")
    ```


    :param Sequence[builtins.str] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
    :param builtins.str id: ID of the network zone to retrieve, conflicts with `name`.
    :param Sequence[builtins.str] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
    :param Sequence[builtins.str] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
    :param builtins.str name: Name of the network zone to retrieve, conflicts with `id`.
    """
    __args__ = dict()
    __args__['dynamicLocationsExcludes'] = dynamic_locations_excludes
    __args__['id'] = id
    __args__['ipServiceCategoriesExcludes'] = ip_service_categories_excludes
    __args__['ipServiceCategoriesIncludes'] = ip_service_categories_includes
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getNetworkZone:getNetworkZone', __args__, opts=opts, typ=GetNetworkZoneResult).value

    return AwaitableGetNetworkZoneResult(
        asns=pulumi.get(__ret__, 'asns'),
        dynamic_locations=pulumi.get(__ret__, 'dynamic_locations'),
        dynamic_locations_excludes=pulumi.get(__ret__, 'dynamic_locations_excludes'),
        dynamic_proxy_type=pulumi.get(__ret__, 'dynamic_proxy_type'),
        gateways=pulumi.get(__ret__, 'gateways'),
        id=pulumi.get(__ret__, 'id'),
        ip_service_categories_excludes=pulumi.get(__ret__, 'ip_service_categories_excludes'),
        ip_service_categories_includes=pulumi.get(__ret__, 'ip_service_categories_includes'),
        name=pulumi.get(__ret__, 'name'),
        proxies=pulumi.get(__ret__, 'proxies'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'),
        usage=pulumi.get(__ret__, 'usage'))
def get_network_zone_output(dynamic_locations_excludes: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                            id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            ip_service_categories_excludes: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                            ip_service_categories_includes: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                            name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkZoneResult]:
    """
    Gets Okta Network Zone.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_network_zone(name="Block Antarctica")
    ```


    :param Sequence[builtins.str] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
    :param builtins.str id: ID of the network zone to retrieve, conflicts with `name`.
    :param Sequence[builtins.str] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
    :param Sequence[builtins.str] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
    :param builtins.str name: Name of the network zone to retrieve, conflicts with `id`.
    """
    __args__ = dict()
    __args__['dynamicLocationsExcludes'] = dynamic_locations_excludes
    __args__['id'] = id
    __args__['ipServiceCategoriesExcludes'] = ip_service_categories_excludes
    __args__['ipServiceCategoriesIncludes'] = ip_service_categories_includes
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getNetworkZone:getNetworkZone', __args__, opts=opts, typ=GetNetworkZoneResult)
    return __ret__.apply(lambda __response__: GetNetworkZoneResult(
        asns=pulumi.get(__response__, 'asns'),
        dynamic_locations=pulumi.get(__response__, 'dynamic_locations'),
        dynamic_locations_excludes=pulumi.get(__response__, 'dynamic_locations_excludes'),
        dynamic_proxy_type=pulumi.get(__response__, 'dynamic_proxy_type'),
        gateways=pulumi.get(__response__, 'gateways'),
        id=pulumi.get(__response__, 'id'),
        ip_service_categories_excludes=pulumi.get(__response__, 'ip_service_categories_excludes'),
        ip_service_categories_includes=pulumi.get(__response__, 'ip_service_categories_includes'),
        name=pulumi.get(__response__, 'name'),
        proxies=pulumi.get(__response__, 'proxies'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type'),
        usage=pulumi.get(__response__, 'usage')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GroupAssignmentArgs', 'GroupAssignment']

@pulumi.input_type
class GroupAssignmentArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[builtins.str],
                 group_id: pulumi.Input[builtins.str],
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 profile: Optional[pulumi.Input[builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a GroupAssignment resource.
        :param pulumi.Input[builtins.str] app_id: App to associate group with
        :param pulumi.Input[builtins.str] group_id: Group associated with the application
        :param pulumi.Input[builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "group_id", group_id)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if retain_assignment is not None:
            pulumi.set(__self__, "retain_assignment", retain_assignment)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[builtins.str]:
        """
        App to associate group with
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[builtins.str]:
        """
        Group associated with the application
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Priority of group assignment.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "profile", value)

    @property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @retain_assignment.setter
    def retain_assignment(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "retain_assignment", value)


@pulumi.input_type
class _GroupAssignmentState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 profile: Optional[pulumi.Input[builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GroupAssignment resources.
        :param pulumi.Input[builtins.str] app_id: App to associate group with
        :param pulumi.Input[builtins.str] group_id: Group associated with the application
        :param pulumi.Input[builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if retain_assignment is not None:
            pulumi.set(__self__, "retain_assignment", retain_assignment)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        App to associate group with
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Group associated with the application
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Priority of group assignment.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "profile", value)

    @property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @retain_assignment.setter
    def retain_assignment(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "retain_assignment", value)


@pulumi.type_token("okta:app/groupAssignment:GroupAssignment")
class GroupAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 profile: Optional[pulumi.Input[builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.GroupAssignment("example",
            app_id="<app id>",
            group_id="<group id>",
            profile=\"\"\"{
          "<app_profile_field>": "<value>"
        }
        \"\"\")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/groupAssignment:GroupAssignment example <app_id>/<group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] app_id: App to associate group with
        :param pulumi.Input[builtins.str] group_id: Group associated with the application
        :param pulumi.Input[builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.GroupAssignment("example",
            app_id="<app id>",
            group_id="<group id>",
            profile=\"\"\"{
          "<app_profile_field>": "<value>"
        }
        \"\"\")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/groupAssignment:GroupAssignment example <app_id>/<group_id>
        ```

        :param str resource_name: The name of the resource.
        :param GroupAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 priority: Optional[pulumi.Input[builtins.int]] = None,
                 profile: Optional[pulumi.Input[builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupAssignmentArgs.__new__(GroupAssignmentArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["priority"] = priority
            __props__.__dict__["profile"] = profile
            __props__.__dict__["retain_assignment"] = retain_assignment
        super(GroupAssignment, __self__).__init__(
            'okta:app/groupAssignment:GroupAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[builtins.str]] = None,
            group_id: Optional[pulumi.Input[builtins.str]] = None,
            priority: Optional[pulumi.Input[builtins.int]] = None,
            profile: Optional[pulumi.Input[builtins.str]] = None,
            retain_assignment: Optional[pulumi.Input[builtins.bool]] = None) -> 'GroupAssignment':
        """
        Get an existing GroupAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] app_id: App to associate group with
        :param pulumi.Input[builtins.str] group_id: Group associated with the application
        :param pulumi.Input[builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupAssignmentState.__new__(_GroupAssignmentState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["priority"] = priority
        __props__.__dict__["profile"] = profile
        __props__.__dict__["retain_assignment"] = retain_assignment
        return GroupAssignment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[builtins.str]:
        """
        App to associate group with
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[builtins.str]:
        """
        Group associated with the application
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def priority(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Priority of group assignment.
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def profile(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        """
        return pulumi.get(self, "profile")

    @property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .admin_role_custom import *
from .admin_role_custom_assignments import *
from .admin_role_targets import *
from .app_group_assignments import *
from .app_oauth_api_scope import *
from .app_saml_app_settings import *
from .app_shared_credentials import *
from .app_signon_policy import *
from .app_signon_policy_rule import *
from .app_user_base_schema_property import *
from .app_user_schema_property import *
from .auth_server_claim_default import *
from .auth_server_default import *
from .authenticator import *
from .behaviour import *
from .brand import *
from .captcha import *
from .captcha_org_wide_settings import *
from .customized_signin_page import *
from .domain import *
from .domain_certificate import *
from .domain_verification import *
from .email_customization import *
from .email_domain import *
from .email_domain_verification import *
from .email_sender import *
from .email_sender_verification import *
from .email_smtp_server import *
from .email_template_settings import *
from .event_hook import *
from .event_hook_verification import *
from .factor_totp import *
from .get_app_group_assignments import *
from .get_app_signon_policy import *
from .get_app_user_assignments import *
from .get_apps import *
from .get_auth_server_claim import *
from .get_auth_server_claims import *
from .get_authenticator import *
from .get_behaviour import *
from .get_behaviours import *
from .get_brand import *
from .get_brands import *
from .get_default_signin_page import *
from .get_device_assurance_policy import *
from .get_domain import *
from .get_email_customization import *
from .get_email_customizations import *
from .get_email_smtp_server import *
from .get_groups import *
from .get_log_stream import *
from .get_network_zone import *
from .get_org_metadata import *
from .get_role_subscription import *
from .get_template import *
from .get_templates import *
from .get_theme import *
from .get_themes import *
from .get_trusted_origins import *
from .get_user_security_questions import *
from .group_memberships import *
from .group_schema_property import *
from .link_definition import *
from .link_value import *
from .log_stream import *
from .org_configuration import *
from .org_support import *
from .policy_mfa_default import *
from .policy_password_default import *
from .policy_profile_enrollment import *
from .policy_profile_enrollment_apps import *
from .policy_rule_profile_enrollment import *
from .preview_signin_page import *
from .provider import *
from .rate_limiting import *
from .resource_set import *
from .role_subscription import *
from .security_notification_emails import *
from .template_sms import *
from .theme import *
from .threat_insight_settings import *
from .trusted_server import *
from .user_admin_roles import *
from .user_base_schema_property import *
from .user_factor_question import *
from .user_group_memberships import *
from .user_schema_property import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_okta.app as __app
    app = __app
    import pulumi_okta.auth as __auth
    auth = __auth
    import pulumi_okta.config as __config
    config = __config
    import pulumi_okta.factor as __factor
    factor = __factor
    import pulumi_okta.group as __group
    group = __group
    import pulumi_okta.idp as __idp
    idp = __idp
    import pulumi_okta.inline as __inline
    inline = __inline
    import pulumi_okta.network as __network
    network = __network
    import pulumi_okta.policy as __policy
    policy = __policy
    import pulumi_okta.profile as __profile
    profile = __profile
    import pulumi_okta.trustedorigin as __trustedorigin
    trustedorigin = __trustedorigin
    import pulumi_okta.user as __user
    user = __user
else:
    app = _utilities.lazy_import('pulumi_okta.app')
    auth = _utilities.lazy_import('pulumi_okta.auth')
    config = _utilities.lazy_import('pulumi_okta.config')
    factor = _utilities.lazy_import('pulumi_okta.factor')
    group = _utilities.lazy_import('pulumi_okta.group')
    idp = _utilities.lazy_import('pulumi_okta.idp')
    inline = _utilities.lazy_import('pulumi_okta.inline')
    network = _utilities.lazy_import('pulumi_okta.network')
    policy = _utilities.lazy_import('pulumi_okta.policy')
    profile = _utilities.lazy_import('pulumi_okta.profile')
    trustedorigin = _utilities.lazy_import('pulumi_okta.trustedorigin')
    user = _utilities.lazy_import('pulumi_okta.user')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "okta",
  "mod": "app/accessPolicyAssignment",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/accessPolicyAssignment:AccessPolicyAssignment": "AccessPolicyAssignment"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/autoLogin",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/autoLogin:AutoLogin": "AutoLogin"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/basicAuth",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/basicAuth:BasicAuth": "BasicAuth"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/bookmark",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/bookmark:Bookmark": "Bookmark"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/groupAssignment",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/groupAssignment:GroupAssignment": "GroupAssignment"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/oAuth",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/oAuth:OAuth": "OAuth"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/oAuthPostLogoutRedirectUri",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/oAuthPostLogoutRedirectUri:OAuthPostLogoutRedirectUri": "OAuthPostLogoutRedirectUri"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/oAuthRedirectUri",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/oAuthRedirectUri:OAuthRedirectUri": "OAuthRedirectUri"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/oauthRoleAssignment",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/oauthRoleAssignment:OauthRoleAssignment": "OauthRoleAssignment"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/saml",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/saml:Saml": "Saml"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/securePasswordStore",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/securePasswordStore:SecurePasswordStore": "SecurePasswordStore"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/swa",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/swa:Swa": "Swa"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/threeField",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/threeField:ThreeField": "ThreeField"
  }
 },
 {
  "pkg": "okta",
  "mod": "app/user",
  "fqn": "pulumi_okta.app",
  "classes": {
   "okta:app/user:User": "User"
  }
 },
 {
  "pkg": "okta",
  "mod": "auth/server",
  "fqn": "pulumi_okta.auth",
  "classes": {
   "okta:auth/server:Server": "Server"
  }
 },
 {
  "pkg": "okta",
  "mod": "auth/serverClaim",
  "fqn": "pulumi_okta.auth",
  "classes": {
   "okta:auth/serverClaim:ServerClaim": "ServerClaim"
  }
 },
 {
  "pkg": "okta",
  "mod": "auth/serverPolicy",
  "fqn": "pulumi_okta.auth",
  "classes": {
   "okta:auth/serverPolicy:ServerPolicy": "ServerPolicy"
  }
 },
 {
  "pkg": "okta",
  "mod": "auth/serverPolicyClaim",
  "fqn": "pulumi_okta.auth",
  "classes": {
   "okta:auth/serverPolicyClaim:ServerPolicyClaim": "ServerPolicyClaim"
  }
 },
 {
  "pkg": "okta",
  "mod": "auth/serverPolicyRule",
  "fqn": "pulumi_okta.auth",
  "classes": {
   "okta:auth/serverPolicyRule:ServerPolicyRule": "ServerPolicyRule"
  }
 },
 {
  "pkg": "okta",
  "mod": "auth/serverScope",
  "fqn": "pulumi_okta.auth",
  "classes": {
   "okta:auth/serverScope:ServerScope": "ServerScope"
  }
 },
 {
  "pkg": "okta",
  "mod": "factor/factor",
  "fqn": "pulumi_okta.factor",
  "classes": {
   "okta:factor/factor:Factor": "Factor"
  }
 },
 {
  "pkg": "okta",
  "mod": "group/group",
  "fqn": "pulumi_okta.group",
  "classes": {
   "okta:group/group:Group": "Group"
  }
 },
 {
  "pkg": "okta",
  "mod": "group/owner",
  "fqn": "pulumi_okta.group",
  "classes": {
   "okta:group/owner:Owner": "Owner"
  }
 },
 {
  "pkg": "okta",
  "mod": "group/role",
  "fqn": "pulumi_okta.group",
  "classes": {
   "okta:group/role:Role": "Role"
  }
 },
 {
  "pkg": "okta",
  "mod": "group/rule",
  "fqn": "pulumi_okta.group",
  "classes": {
   "okta:group/rule:Rule": "Rule"
  }
 },
 {
  "pkg": "okta",
  "mod": "idp/oidc",
  "fqn": "pulumi_okta.idp",
  "classes": {
   "okta:idp/oidc:Oidc": "Oidc"
  }
 },
 {
  "pkg": "okta",
  "mod": "idp/saml",
  "fqn": "pulumi_okta.idp",
  "classes": {
   "okta:idp/saml:Saml": "Saml"
  }
 },
 {
  "pkg": "okta",
  "mod": "idp/samlKey",
  "fqn": "pulumi_okta.idp",
  "classes": {
   "okta:idp/samlKey:SamlKey": "SamlKey"
  }
 },
 {
  "pkg": "okta",
  "mod": "idp/social",
  "fqn": "pulumi_okta.idp",
  "classes": {
   "okta:idp/social:Social": "Social"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/adminRoleCustom",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/adminRoleCustom:AdminRoleCustom": "AdminRoleCustom"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/adminRoleCustomAssignments",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/adminRoleCustomAssignments:AdminRoleCustomAssignments": "AdminRoleCustomAssignments"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/adminRoleTargets",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/adminRoleTargets:AdminRoleTargets": "AdminRoleTargets"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appGroupAssignments",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appGroupAssignments:AppGroupAssignments": "AppGroupAssignments"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appOauthApiScope",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appOauthApiScope:AppOauthApiScope": "AppOauthApiScope"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appSamlAppSettings",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appSamlAppSettings:AppSamlAppSettings": "AppSamlAppSettings"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appSharedCredentials",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appSharedCredentials:AppSharedCredentials": "AppSharedCredentials"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appSignonPolicy",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appSignonPolicy:AppSignonPolicy": "AppSignonPolicy"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appSignonPolicyRule",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appSignonPolicyRule:AppSignonPolicyRule": "AppSignonPolicyRule"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appUserBaseSchemaProperty",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appUserBaseSchemaProperty:AppUserBaseSchemaProperty": "AppUserBaseSchemaProperty"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/appUserSchemaProperty",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/appUserSchemaProperty:AppUserSchemaProperty": "AppUserSchemaProperty"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/authServerClaimDefault",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/authServerClaimDefault:AuthServerClaimDefault": "AuthServerClaimDefault"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/authServerDefault",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/authServerDefault:AuthServerDefault": "AuthServerDefault"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/authenticator",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/authenticator:Authenticator": "Authenticator"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/behaviour",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/behaviour:Behaviour": "Behaviour"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/brand",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/brand:Brand": "Brand"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/captcha",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/captcha:Captcha": "Captcha"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/captchaOrgWideSettings",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/captchaOrgWideSettings:CaptchaOrgWideSettings": "CaptchaOrgWideSettings"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/customizedSigninPage",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/customizedSigninPage:CustomizedSigninPage": "CustomizedSigninPage"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/domain",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/domainCertificate",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/domainCertificate:DomainCertificate": "DomainCertificate"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/domainVerification",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/domainVerification:DomainVerification": "DomainVerification"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailCustomization",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailCustomization:EmailCustomization": "EmailCustomization"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailDomain",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailDomain:EmailDomain": "EmailDomain"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailDomainVerification",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailDomainVerification:EmailDomainVerification": "EmailDomainVerification"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailSender",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailSender:EmailSender": "EmailSender"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailSenderVerification",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailSenderVerification:EmailSenderVerification": "EmailSenderVerification"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailSmtpServer",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailSmtpServer:EmailSmtpServer": "EmailSmtpServer"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/emailTemplateSettings",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/emailTemplateSettings:EmailTemplateSettings": "EmailTemplateSettings"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/eventHook",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/eventHook:EventHook": "EventHook"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/eventHookVerification",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/eventHookVerification:EventHookVerification": "EventHookVerification"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/factorTotp",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/factorTotp:FactorTotp": "FactorTotp"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/groupMemberships",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/groupMemberships:GroupMemberships": "GroupMemberships"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/groupSchemaProperty",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/groupSchemaProperty:GroupSchemaProperty": "GroupSchemaProperty"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/linkDefinition",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/linkDefinition:LinkDefinition": "LinkDefinition"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/linkValue",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/linkValue:LinkValue": "LinkValue"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/logStream",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/logStream:LogStream": "LogStream"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/orgConfiguration",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/orgConfiguration:OrgConfiguration": "OrgConfiguration"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/orgSupport",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/orgSupport:OrgSupport": "OrgSupport"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/policyMfaDefault",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/policyMfaDefault:PolicyMfaDefault": "PolicyMfaDefault"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/policyPasswordDefault",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/policyPasswordDefault:PolicyPasswordDefault": "PolicyPasswordDefault"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/policyProfileEnrollment",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/policyProfileEnrollment:PolicyProfileEnrollment": "PolicyProfileEnrollment"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/policyProfileEnrollmentApps",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/policyProfileEnrollmentApps:PolicyProfileEnrollmentApps": "PolicyProfileEnrollmentApps"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/policyRuleProfileEnrollment",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/policyRuleProfileEnrollment:PolicyRuleProfileEnrollment": "PolicyRuleProfileEnrollment"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/previewSigninPage",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/previewSigninPage:PreviewSigninPage": "PreviewSigninPage"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/rateLimiting",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/rateLimiting:RateLimiting": "RateLimiting"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/resourceSet",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/resourceSet:ResourceSet": "ResourceSet"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/roleSubscription",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/roleSubscription:RoleSubscription": "RoleSubscription"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/securityNotificationEmails",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/securityNotificationEmails:SecurityNotificationEmails": "SecurityNotificationEmails"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/templateSms",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/templateSms:TemplateSms": "TemplateSms"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/theme",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/theme:Theme": "Theme"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/threatInsightSettings",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/threatInsightSettings:ThreatInsightSettings": "ThreatInsightSettings"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/trustedServer",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/trustedServer:TrustedServer": "TrustedServer"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/userAdminRoles",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/userAdminRoles:UserAdminRoles": "UserAdminRoles"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/userBaseSchemaProperty",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/userBaseSchemaProperty:UserBaseSchemaProperty": "UserBaseSchemaProperty"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/userFactorQuestion",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/userFactorQuestion:UserFactorQuestion": "UserFactorQuestion"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/userGroupMemberships",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/userGroupMemberships:UserGroupMemberships": "UserGroupMemberships"
  }
 },
 {
  "pkg": "okta",
  "mod": "index/userSchemaProperty",
  "fqn": "pulumi_okta",
  "classes": {
   "okta:index/userSchemaProperty:UserSchemaProperty": "UserSchemaProperty"
  }
 },
 {
  "pkg": "okta",
  "mod": "inline/hook",
  "fqn": "pulumi_okta.inline",
  "classes": {
   "okta:inline/hook:Hook": "Hook"
  }
 },
 {
  "pkg": "okta",
  "mod": "network/zone",
  "fqn": "pulumi_okta.network",
  "classes": {
   "okta:network/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/deviceAssuranceAndroid",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/deviceAssuranceAndroid:DeviceAssuranceAndroid": "DeviceAssuranceAndroid"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/deviceAssuranceChromeos",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/deviceAssuranceChromeos:DeviceAssuranceChromeos": "DeviceAssuranceChromeos"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/deviceAssuranceIos",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/deviceAssuranceIos:DeviceAssuranceIos": "DeviceAssuranceIos"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/deviceAssuranceMacos",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/deviceAssuranceMacos:DeviceAssuranceMacos": "DeviceAssuranceMacos"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/deviceAssuranceWindows",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/deviceAssuranceWindows:DeviceAssuranceWindows": "DeviceAssuranceWindows"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/mfa",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/mfa:Mfa": "Mfa"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/password",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/password:Password": "Password"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/ruleIdpDiscovery",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/ruleIdpDiscovery:RuleIdpDiscovery": "RuleIdpDiscovery"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/ruleMfa",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/ruleMfa:RuleMfa": "RuleMfa"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/rulePassword",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/rulePassword:RulePassword": "RulePassword"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/ruleSignon",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/ruleSignon:RuleSignon": "RuleSignon"
  }
 },
 {
  "pkg": "okta",
  "mod": "policy/signon",
  "fqn": "pulumi_okta.policy",
  "classes": {
   "okta:policy/signon:Signon": "Signon"
  }
 },
 {
  "pkg": "okta",
  "mod": "profile/mapping",
  "fqn": "pulumi_okta.profile",
  "classes": {
   "okta:profile/mapping:Mapping": "Mapping"
  }
 },
 {
  "pkg": "okta",
  "mod": "trustedorigin/origin",
  "fqn": "pulumi_okta.trustedorigin",
  "classes": {
   "okta:trustedorigin/origin:Origin": "Origin"
  }
 },
 {
  "pkg": "okta",
  "mod": "user/user",
  "fqn": "pulumi_okta.user",
  "classes": {
   "okta:user/user:User": "User"
  }
 },
 {
  "pkg": "okta",
  "mod": "user/userType",
  "fqn": "pulumi_okta.user",
  "classes": {
   "okta:user/userType:UserType": "UserType"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "okta",
  "token": "pulumi:providers:okta",
  "fqn": "pulumi_okta",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetBehavioursResult',
    'AwaitableGetBehavioursResult',
    'get_behaviours',
    'get_behaviours_output',
]

@pulumi.output_type
class GetBehavioursResult:
    """
    A collection of values returned by getBehaviours.
    """
    def __init__(__self__, behaviors=None, id=None, q=None):
        if behaviors and not isinstance(behaviors, list):
            raise TypeError("Expected argument 'behaviors' to be a list")
        pulumi.set(__self__, "behaviors", behaviors)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if q and not isinstance(q, str):
            raise TypeError("Expected argument 'q' to be a str")
        pulumi.set(__self__, "q", q)

    @property
    @pulumi.getter
    def behaviors(self) -> Sequence['outputs.GetBehavioursBehaviorResult']:
        return pulumi.get(self, "behaviors")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def q(self) -> Optional[builtins.str]:
        """
        Searches the name property of behaviors for matching value
        """
        return pulumi.get(self, "q")


class AwaitableGetBehavioursResult(GetBehavioursResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBehavioursResult(
            behaviors=self.behaviors,
            id=self.id,
            q=self.q)


def get_behaviours(q: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBehavioursResult:
    """
    Get a behaviors by search criteria.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_behaviours(q="New")
    ```


    :param builtins.str q: Searches the name property of behaviors for matching value
    """
    __args__ = dict()
    __args__['q'] = q
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getBehaviours:getBehaviours', __args__, opts=opts, typ=GetBehavioursResult).value

    return AwaitableGetBehavioursResult(
        behaviors=pulumi.get(__ret__, 'behaviors'),
        id=pulumi.get(__ret__, 'id'),
        q=pulumi.get(__ret__, 'q'))
def get_behaviours_output(q: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBehavioursResult]:
    """
    Get a behaviors by search criteria.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_behaviours(q="New")
    ```


    :param builtins.str q: Searches the name property of behaviors for matching value
    """
    __args__ = dict()
    __args__['q'] = q
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getBehaviours:getBehaviours', __args__, opts=opts, typ=GetBehavioursResult)
    return __ret__.apply(lambda __response__: GetBehavioursResult(
        behaviors=pulumi.get(__response__, 'behaviors'),
        id=pulumi.get(__response__, 'id'),
        q=pulumi.get(__response__, 'q')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, delay_read_seconds=None, description=None, id=None, include_users=None, name=None, type=None, users=None):
        if delay_read_seconds and not isinstance(delay_read_seconds, str):
            raise TypeError("Expected argument 'delay_read_seconds' to be a str")
        pulumi.set(__self__, "delay_read_seconds", delay_read_seconds)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_users and not isinstance(include_users, bool):
            raise TypeError("Expected argument 'include_users' to be a bool")
        pulumi.set(__self__, "include_users", include_users)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="delayReadSeconds")
    def delay_read_seconds(self) -> Optional[builtins.str]:
        """
        Force delay of the group read by N seconds. Useful when eventual consistency of group information needs to be allowed for; for instance, when group rules are known to have been applied.
        """
        return pulumi.get(self, "delay_read_seconds")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="includeUsers")
    def include_users(self) -> Optional[builtins.bool]:
        """
        Fetch group users, having default off cuts down on API calls.
        """
        return pulumi.get(self, "include_users")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def users(self) -> Sequence[builtins.str]:
        """
        Users associated with the group. This can also be done per user.
        """
        return pulumi.get(self, "users")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            delay_read_seconds=self.delay_read_seconds,
            description=self.description,
            id=self.id,
            include_users=self.include_users,
            name=self.name,
            type=self.type,
            users=self.users)


def get_group(delay_read_seconds: Optional[builtins.str] = None,
              id: Optional[builtins.str] = None,
              include_users: Optional[builtins.bool] = None,
              name: Optional[builtins.str] = None,
              type: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    Get a group from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.group.get_group(name="Example App")
    ```


    :param builtins.str delay_read_seconds: Force delay of the group read by N seconds. Useful when eventual consistency of group information needs to be allowed for; for instance, when group rules are known to have been applied.
    :param builtins.str id: ID of group.
    :param builtins.bool include_users: Fetch group users, having default off cuts down on API calls.
    :param builtins.str name: Name of group.
    """
    __args__ = dict()
    __args__['delayReadSeconds'] = delay_read_seconds
    __args__['id'] = id
    __args__['includeUsers'] = include_users
    __args__['name'] = name
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:group/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        delay_read_seconds=pulumi.get(__ret__, 'delay_read_seconds'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        include_users=pulumi.get(__ret__, 'include_users'),
        name=pulumi.get(__ret__, 'name'),
        type=pulumi.get(__ret__, 'type'),
        users=pulumi.get(__ret__, 'users'))
def get_group_output(delay_read_seconds: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     include_users: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                     name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    Get a group from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.group.get_group(name="Example App")
    ```


    :param builtins.str delay_read_seconds: Force delay of the group read by N seconds. Useful when eventual consistency of group information needs to be allowed for; for instance, when group rules are known to have been applied.
    :param builtins.str id: ID of group.
    :param builtins.bool include_users: Fetch group users, having default off cuts down on API calls.
    :param builtins.str name: Name of group.
    """
    __args__ = dict()
    __args__['delayReadSeconds'] = delay_read_seconds
    __args__['id'] = id
    __args__['includeUsers'] = include_users
    __args__['name'] = name
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:group/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        delay_read_seconds=pulumi.get(__response__, 'delay_read_seconds'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        include_users=pulumi.get(__response__, 'include_users'),
        name=pulumi.get(__response__, 'name'),
        type=pulumi.get(__response__, 'type'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserTypeResult',
    'AwaitableGetUserTypeResult',
    'get_user_type',
    'get_user_type_output',
]

@pulumi.output_type
class GetUserTypeResult:
    """
    A collection of values returned by getUserType.
    """
    def __init__(__self__, description=None, display_name=None, id=None, name=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of user type.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Display name of user type.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        ID of the user type to retrieve, conflicts with `name`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        Name of user type to retrieve, conflicts with `id`.
        """
        return pulumi.get(self, "name")


class AwaitableGetUserTypeResult(GetUserTypeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserTypeResult(
            description=self.description,
            display_name=self.display_name,
            id=self.id,
            name=self.name)


def get_user_type(id: Optional[builtins.str] = None,
                  name: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserTypeResult:
    """
    Get a user type from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.user.get_user_type(name="example")
    ```


    :param builtins.str id: ID of the user type to retrieve, conflicts with `name`.
    :param builtins.str name: Name of user type to retrieve, conflicts with `id`.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:user/getUserType:getUserType', __args__, opts=opts, typ=GetUserTypeResult).value

    return AwaitableGetUserTypeResult(
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_user_type_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserTypeResult]:
    """
    Get a user type from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.user.get_user_type(name="example")
    ```


    :param builtins.str id: ID of the user type to retrieve, conflicts with `name`.
    :param builtins.str name: Name of user type to retrieve, conflicts with `id`.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:user/getUserType:getUserType', __args__, opts=opts, typ=GetUserTypeResult)
    return __ret__.apply(lambda __response__: GetUserTypeResult(
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EmailDomainArgs', 'EmailDomain']

@pulumi.input_type
class EmailDomainArgs:
    def __init__(__self__, *,
                 brand_id: pulumi.Input[builtins.str],
                 display_name: pulumi.Input[builtins.str],
                 domain: pulumi.Input[builtins.str],
                 user_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a EmailDomain resource.
        :param pulumi.Input[builtins.str] brand_id: Brand id of the email domain.
        :param pulumi.Input[builtins.str] display_name: Display name of the email domain.
        :param pulumi.Input[builtins.str] domain: Mail domain to send from.
        :param pulumi.Input[builtins.str] user_name: User name of the email domain.
        """
        pulumi.set(__self__, "brand_id", brand_id)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Input[builtins.str]:
        """
        Brand id of the email domain.
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "brand_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[builtins.str]:
        """
        Display name of the email domain.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        Mail domain to send from.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Input[builtins.str]:
        """
        User name of the email domain.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _EmailDomainState:
    def __init__(__self__, *,
                 brand_id: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 dns_validation_records: Optional[pulumi.Input[Sequence[pulumi.Input['EmailDomainDnsValidationRecordArgs']]]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 validation_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering EmailDomain resources.
        :param pulumi.Input[builtins.str] brand_id: Brand id of the email domain.
        :param pulumi.Input[builtins.str] display_name: Display name of the email domain.
        :param pulumi.Input[Sequence[pulumi.Input['EmailDomainDnsValidationRecordArgs']]] dns_validation_records: TXT and cname records to be registered for the email Domain
        :param pulumi.Input[builtins.str] domain: Mail domain to send from.
        :param pulumi.Input[builtins.str] user_name: User name of the email domain.
        :param pulumi.Input[builtins.str] validation_status: Status of the email domain. Values: NOT*STARTED, IN*PROGRESS, VERIFIED, COMPLETED
        """
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if dns_validation_records is not None:
            pulumi.set(__self__, "dns_validation_records", dns_validation_records)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if validation_status is not None:
            pulumi.set(__self__, "validation_status", validation_status)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Brand id of the email domain.
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Display name of the email domain.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="dnsValidationRecords")
    def dns_validation_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EmailDomainDnsValidationRecordArgs']]]]:
        """
        TXT and cname records to be registered for the email Domain
        """
        return pulumi.get(self, "dns_validation_records")

    @dns_validation_records.setter
    def dns_validation_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EmailDomainDnsValidationRecordArgs']]]]):
        pulumi.set(self, "dns_validation_records", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Mail domain to send from.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        User name of the email domain.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)

    @property
    @pulumi.getter(name="validationStatus")
    def validation_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status of the email domain. Values: NOT*STARTED, IN*PROGRESS, VERIFIED, COMPLETED
        """
        return pulumi.get(self, "validation_status")

    @validation_status.setter
    def validation_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "validation_status", value)


@pulumi.type_token("okta:index/emailDomain:EmailDomain")
class EmailDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 brand_id: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EmailDomain("example",
            brand_id="abc123",
            domain="example.com",
            display_name="test",
            user_name="paul_atreides")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/emailDomain:EmailDomain example <domain_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] brand_id: Brand id of the email domain.
        :param pulumi.Input[builtins.str] display_name: Display name of the email domain.
        :param pulumi.Input[builtins.str] domain: Mail domain to send from.
        :param pulumi.Input[builtins.str] user_name: User name of the email domain.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EmailDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EmailDomain("example",
            brand_id="abc123",
            domain="example.com",
            display_name="test",
            user_name="paul_atreides")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/emailDomain:EmailDomain example <domain_id>
        ```

        :param str resource_name: The name of the resource.
        :param EmailDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EmailDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 brand_id: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EmailDomainArgs.__new__(EmailDomainArgs)

            if brand_id is None and not opts.urn:
                raise TypeError("Missing required property 'brand_id'")
            __props__.__dict__["brand_id"] = brand_id
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__.__dict__["user_name"] = user_name
            __props__.__dict__["dns_validation_records"] = None
            __props__.__dict__["validation_status"] = None
        super(EmailDomain, __self__).__init__(
            'okta:index/emailDomain:EmailDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            brand_id: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            dns_validation_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EmailDomainDnsValidationRecordArgs', 'EmailDomainDnsValidationRecordArgsDict']]]]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            user_name: Optional[pulumi.Input[builtins.str]] = None,
            validation_status: Optional[pulumi.Input[builtins.str]] = None) -> 'EmailDomain':
        """
        Get an existing EmailDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] brand_id: Brand id of the email domain.
        :param pulumi.Input[builtins.str] display_name: Display name of the email domain.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EmailDomainDnsValidationRecordArgs', 'EmailDomainDnsValidationRecordArgsDict']]]] dns_validation_records: TXT and cname records to be registered for the email Domain
        :param pulumi.Input[builtins.str] domain: Mail domain to send from.
        :param pulumi.Input[builtins.str] user_name: User name of the email domain.
        :param pulumi.Input[builtins.str] validation_status: Status of the email domain. Values: NOT*STARTED, IN*PROGRESS, VERIFIED, COMPLETED
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EmailDomainState.__new__(_EmailDomainState)

        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["dns_validation_records"] = dns_validation_records
        __props__.__dict__["domain"] = domain
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["validation_status"] = validation_status
        return EmailDomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Output[builtins.str]:
        """
        Brand id of the email domain.
        """
        return pulumi.get(self, "brand_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Display name of the email domain.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="dnsValidationRecords")
    def dns_validation_records(self) -> pulumi.Output[Sequence['outputs.EmailDomainDnsValidationRecord']]:
        """
        TXT and cname records to be registered for the email Domain
        """
        return pulumi.get(self, "dns_validation_records")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        Mail domain to send from.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[builtins.str]:
        """
        User name of the email domain.
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="validationStatus")
    def validation_status(self) -> pulumi.Output[builtins.str]:
        """
        Status of the email domain. Values: NOT*STARTED, IN*PROGRESS, VERIFIED, COMPLETED
        """
        return pulumi.get(self, "validation_status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'MappingMappingArgs',
    'MappingMappingArgsDict',
]

MYPY = False

if not MYPY:
    class MappingMappingArgsDict(TypedDict):
        expression: pulumi.Input[builtins.str]
        id: pulumi.Input[builtins.str]
        """
        The mapping property key.
        """
        push_status: NotRequired[pulumi.Input[builtins.str]]
elif False:
    MappingMappingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MappingMappingArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[builtins.str],
                 id: pulumi.Input[builtins.str],
                 push_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] id: The mapping property key.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "id", id)
        if push_status is not None:
            pulumi.set(__self__, "push_status", push_status)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[builtins.str]:
        """
        The mapping property key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="pushStatus")
    def push_status(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "push_status")

    @push_status.setter
    def push_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "push_status", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPolicyResult',
    'AwaitableGetPolicyResult',
    'get_policy',
    'get_policy_output',
]

@pulumi.output_type
class GetPolicyResult:
    """
    A collection of values returned by getPolicy.
    """
    def __init__(__self__, id=None, name=None, status=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the policy
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the policy
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Policy type, see https://developer.okta.com/docs/reference/api/policy/#policy-object
        """
        return pulumi.get(self, "type")


class AwaitableGetPolicyResult(GetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyResult(
            id=self.id,
            name=self.name,
            status=self.status,
            type=self.type)


def get_policy(name: Optional[builtins.str] = None,
               type: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyResult:
    """
    Get a policy from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.policy.get_policy(name="Password Policy Example",
        type="PASSWORD")
    ```


    :param builtins.str name: Name of the policy
    :param builtins.str type: Policy type, see https://developer.okta.com/docs/reference/api/policy/#policy-object
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:policy/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult).value

    return AwaitableGetPolicyResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_policy_output(name: Optional[pulumi.Input[builtins.str]] = None,
                      type: Optional[pulumi.Input[builtins.str]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicyResult]:
    """
    Get a policy from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.policy.get_policy(name="Password Policy Example",
        type="PASSWORD")
    ```


    :param builtins.str name: Name of the policy
    :param builtins.str type: Policy type, see https://developer.okta.com/docs/reference/api/policy/#policy-object
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:policy/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult)
    return __ret__.apply(lambda __response__: GetPolicyResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))
